@@ -34,7 +34,7 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-//@line 38 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/xulrunner/app/xulrunner.js"
+//@line 38 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/xulrunner/app/xulrunner.js"
 
 // We need to override the default values of these preferences since all.js
 // assumes these are in the navigator package, which for us is non-existant.
@@ -54,3 +54,13 @@ pref("intl.charset.detector", "chrome://global/locale/intl.properties");
 pref("intl.charset.default",  "chrome://global-platform/locale/intl.properties");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
+pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
+pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul");
+pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul");
+pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager");
+pref("xpinstall.dialog.progress.type.skin", "Extension:Manager");
+pref("xpinstall.enabled", true);
+//@line 66 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/xulrunner/app/xulrunner.js"
+pref("browser.preferences.instantApply", true);
+//@line 71 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/xulrunner/app/xulrunner.js"
+pref("browser.preferences.animateFadeIn", false);
